.. _api_parsers:

=======
Parsers
=======

Classes to read data from ISA-Tab investigation, study and assay files and create the corresponding AltamISA models.
Note that parsers can issue warnings, see :ref:`api_validators` on how to capture them properly.

.. contents::

altamisa.isatab.InvestigationReader
-----------------------------------

.. autoclass:: altamisa.isatab.InvestigationReader
    :members:

altamisa.isatab.AssayReader
---------------------------

.. autoclass:: altamisa.isatab.AssayReader
    :members:

altamisa.isatab.AssayRowReader
------------------------------

.. autoclass:: altamisa.isatab.AssayRowReader
    :members:

altamisa.isatab.StudyReader
---------------------------

.. autoclass:: altamisa.isatab.StudyReader
    :members:

altamisa.isatab.StudyRowReader
------------------------------

.. autoclass:: altamisa.isatab.StudyRowReader
    :members:
